@@ -29,7 +29,7 @@
 #' expected number of tests, pooling sensitivity, pooling specificity, pooling
 #' positive predictive value, and pooling negative predictive value for the algorithm.
 #' See Hitt et al. (2018) or Black et al. (2015) at 
-#' \url{http://chrisbilder.com/grouptesting} for additional details on the 
+#' \url{http://chrisbilder.com/grouptesting/} for additional details on the 
 #' implementation of informative three-stage hierarchical testing.
 #' 
 #' The value(s) specified by \kbd{group.sz} represent the initial (stage 1) 
@@ -94,7 +94,7 @@
 #' and \code{\link{OTC}} for finding the optimal testing configuration for a
 #' number of standard group testing algorithms.
 #'
-#' \url{http://chrisbilder.com/grouptesting}
+#' \url{http://chrisbilder.com/grouptesting/}
 #'
 #' @family OTC functions
 #'
@@ -235,25 +235,25 @@ Inf.D3 <- function(p, Se, Sp, group.sz, obj.fn, weights=NULL, alpha=2){
     
     # find the best configuration for each initial group size I, out of all possible configurations
     save.ET[count,] <- save.it[save.it[,(max(set.of.I)+6)]==min(save.it[,(max(set.of.I)+6)]), c(1:(max(set.of.I)+5),(max(set.of.I)+6),(max(set.of.I)+14):ncol(save.it))]
-    if(class(try(save.MAR[count,] <- save.it[save.it[,(max(set.of.I)+7)]==min(save.it[,(max(set.of.I)+7)]), c(1:(max(set.of.I)+5),(max(set.of.I)+7),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try(save.MAR[count,] <- save.it[save.it[,(max(set.of.I)+7)]==min(save.it[,(max(set.of.I)+7)]), c(1:(max(set.of.I)+5),(max(set.of.I)+7),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.MAR[count,] <- save.it[save.it[,(max(set.of.I)+7)]==min(save.it[,(max(set.of.I)+7)]), c(1:(max(set.of.I)+5),(max(set.of.I)+7),(max(set.of.I)+14):ncol(save.it))]
     }
-    if(class(try(save.GR1[count,] <- save.it[save.it[,(max(set.of.I)+8)]==min(save.it[,(max(set.of.I)+8)]), c(1:(max(set.of.I)+5),(max(set.of.I)+8),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try(save.GR1[count,] <- save.it[save.it[,(max(set.of.I)+8)]==min(save.it[,(max(set.of.I)+8)]), c(1:(max(set.of.I)+5),(max(set.of.I)+8),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.GR1[count,] <- save.it[save.it[,(max(set.of.I)+8)]==min(save.it[,(max(set.of.I)+8)]), c(1:(max(set.of.I)+5),(max(set.of.I)+8),(max(set.of.I)+14):ncol(save.it))]
     }
-    if(class(try(save.GR2[count,] <- save.it[save.it[,(max(set.of.I)+9)]==min(save.it[,(max(set.of.I)+9)]), c(1:(max(set.of.I)+5),(max(set.of.I)+9),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try(save.GR2[count,] <- save.it[save.it[,(max(set.of.I)+9)]==min(save.it[,(max(set.of.I)+9)]), c(1:(max(set.of.I)+5),(max(set.of.I)+9),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.GR2[count,] <- save.it[save.it[,(max(set.of.I)+9)]==min(save.it[,(max(set.of.I)+9)]), c(1:(max(set.of.I)+5),(max(set.of.I)+9),(max(set.of.I)+14):ncol(save.it))]
     }
-    if(class(try(save.GR3[count,] <- save.it[save.it[,(max(set.of.I)+10)]==min(save.it[,(max(set.of.I)+10)]), c(1:(max(set.of.I)+5),(max(set.of.I)+10),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try(save.GR3[count,] <- save.it[save.it[,(max(set.of.I)+10)]==min(save.it[,(max(set.of.I)+10)]), c(1:(max(set.of.I)+5),(max(set.of.I)+10),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.GR3[count,] <- save.it[save.it[,(max(set.of.I)+10)]==min(save.it[,(max(set.of.I)+10)]), c(1:(max(set.of.I)+5),(max(set.of.I)+10),(max(set.of.I)+14):ncol(save.it))]
     }
-    if(class(try(save.GR4[count,] <- save.it[save.it[,(max(set.of.I)+11)]==min(save.it[,(max(set.of.I)+11)]), c(1:(max(set.of.I)+5),(max(set.of.I)+11),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try(save.GR4[count,] <- save.it[save.it[,(max(set.of.I)+11)]==min(save.it[,(max(set.of.I)+11)]), c(1:(max(set.of.I)+5),(max(set.of.I)+11),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.GR4[count,] <- save.it[save.it[,(max(set.of.I)+11)]==min(save.it[,(max(set.of.I)+11)]), c(1:(max(set.of.I)+5),(max(set.of.I)+11),(max(set.of.I)+14):ncol(save.it))]
     }
-    if(class(try( save.GR5[count,] <- save.it[save.it[,(max(set.of.I)+12)]==min(save.it[,(max(set.of.I)+12)]), c(1:(max(set.of.I)+5),(max(set.of.I)+12),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try( save.GR5[count,] <- save.it[save.it[,(max(set.of.I)+12)]==min(save.it[,(max(set.of.I)+12)]), c(1:(max(set.of.I)+5),(max(set.of.I)+12),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.GR5[count,] <- save.it[save.it[,(max(set.of.I)+12)]==min(save.it[,(max(set.of.I)+12)]), c(1:(max(set.of.I)+5),(max(set.of.I)+12),(max(set.of.I)+14):ncol(save.it))]
     }
-    if(class(try(save.GR6[count,] <- save.it[save.it[,(max(set.of.I)+13)]==min(save.it[,(max(set.of.I)+13)]), c(1:(max(set.of.I)+5),(max(set.of.I)+13),(max(set.of.I)+14):ncol(save.it))],silent=T))!="try-error"){
+    if(!inherits(try(save.GR6[count,] <- save.it[save.it[,(max(set.of.I)+13)]==min(save.it[,(max(set.of.I)+13)]), c(1:(max(set.of.I)+5),(max(set.of.I)+13),(max(set.of.I)+14):ncol(save.it))],silent=T), "try-error")){
       save.GR6[count,] <- save.it[save.it[,(max(set.of.I)+13)]==min(save.it[,(max(set.of.I)+13)]), c(1:(max(set.of.I)+5),(max(set.of.I)+13),(max(set.of.I)+14):ncol(save.it))]    
     }
     
