@@ -142,7 +142,6 @@ kappa<-qnorm(conf.level)
 eta<-(kappa^2)/3 + 1/6
 gamma1<-((13/18)*kappa^2 + 17/18)*(-1)
 gamma2<-(kappa^2)/18 + 7/36
-
 midpo<-(y+eta)/(n+2*eta)
 
 if(alternative=="less")
@@ -157,11 +156,13 @@ kappa<-qnorm(1-(1-conf.level)/2)
 eta<-(kappa^2)/3 + 1/6
 gamma1<-((13/18)*kappa^2 + 17/18)*(-1)
 gamma2<-(kappa^2)/18 + 7/36
+midpo<-(y+eta)/(n+2*eta)
 
 CI=c( midpo - kappa*sqrt(esti*(1-esti) + (gamma1*esti*(1-esti) + gamma2)/n)/sqrt(n) , 
  midpo + kappa*sqrt(esti*(1-esti) + (gamma1*esti*(1-esti) + gamma2)/n)/sqrt(n) )
 }
-CI
+CIc <- c(min(CI[1], esti), max(CI[2], esti))
+CIc
 }
 
 "binWald" <-
